@@ -1,9 +1,9 @@
 # et:ts=4
 # portimage.tcl
-# $Id$
+# $Id: portimage.tcl 53660 2009-07-11 10:43:29Z jmr@macports.org $
 #
 # Copyright (c) 2004 Will Barton <wbb4@opendarwin.org>
-# Copyright (c) 2002 Apple Computer, Inc.
+# Copyright (c) 2002 Apple Inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -14,7 +14,7 @@
 # 2. Redistributions in binary form must reproduce the above copyright
 #    notice, this list of conditions and the following disclaimer in the
 #    documentation and/or other materials provided with the distribution.
-# 3. Neither the name of Apple Computer, Inc. nor the names of its contributors
+# 3. Neither the name of Apple Inc. nor the names of its contributors
 #    may be used to endorse or promote products derived from this software
 #    without specific prior written permission.
 #
@@ -43,7 +43,7 @@ set UI_PREFIX "--> "
 #
 # Port Images are basically just installations of the destroot of a port into
 # ${macports::registry.path}/software/${name}/${version}_${revision}${variants}
-# They allow the user to instal multiple versions of the same port, treating
+# They allow the user to install multiple versions of the same port, treating
 # each revision and each different combination of variants as a "version".
 #
 # From there, the user can "activate" a port image.  This creates {sym,hard}links for
@@ -57,9 +57,6 @@ set UI_PREFIX "--> "
 # will also remove all of the references of the files from the registry's
 # file_map
 #
-# Compacting and Uncompacting of port images to save space will be implemented
-# at some point.
-#
 # For the creating and removing of links during activation and deactivation,
 # code very similar to what is used in portinstall is used.
 #
@@ -77,7 +74,11 @@ proc activate {name specifier optionslist} {
         set force 0
     }
 
-    ui_msg "$UI_PREFIX [format [msgcat::mc "Activating %s %s"] $name $specifier]"
+    if {$specifier != ""} {
+            ui_msg "$UI_PREFIX [format [msgcat::mc "Activating %s @%s"] $name $specifier]"
+    } else {
+            ui_msg "$UI_PREFIX [format [msgcat::mc "Activating %s"] $name]"
+    }
 
     registry::read {
 
@@ -110,11 +111,6 @@ proc activate {name specifier optionslist} {
         if { [string equal [$requested state] "active"] } {
             return -code error "Image error: ${name} @${version}_${revision}${variants} is already active."
         }
-
-        # compaction is not yet supported
-        #if { [$requested compact] != 0 } {
-        #    return -code error "Image error: ${name} @${version}_${revision}${variants} is compacted."
-        #}
     }
 
     _activate_contents $port $force
@@ -131,7 +127,11 @@ proc deactivate {name spec optionslist} {
         set force 0
     }
 
-    ui_msg "$UI_PREFIX [format [msgcat::mc "Deactivating %s %s"] $name $v]"
+    if {$spec != ""} {
+            ui_msg "$UI_PREFIX [format [msgcat::mc "Deactivating %s @%s"] $name $spec]"
+    } else {
+            ui_msg "$UI_PREFIX [format [msgcat::mc "Deactivating %s"] $name]"
+    }
 
     if { [string equal $name {}] } {
         throw registry::image-error "Registry error: Please specify the name of the port."
@@ -158,11 +158,6 @@ proc deactivate {name spec optionslist} {
         return -code error "Image error: ${name} @${specifier} is not active."
     }
 
-    # compaction not yet supported
-    #if { [registry::property_retrieve $ref compact] != 0 } {
-    #    return -code error "Image error: ${name} @${specifier} is compacted."
-    #}
-
     registry::check_dependents $port $force
 
     set imagedir [$requested imagedir]
@@ -172,18 +167,6 @@ proc deactivate {name spec optionslist} {
     $requested state imaged
 }
 
-proc compact {name v} {
-    global UI_PREFIX
-
-    throw registry::image-error "Image error: compact/uncompact not yet implemented."
-}
-
-proc uncompact {name v} {
-    global UI_PREFIX
-
-    throw registry::image-error "Image error: compact/uncompact not yet implemented."
-}
-
 proc _check_registry {name specifier} {
     global UI_PREFIX
 
@@ -246,10 +229,10 @@ proc _activate_file {srcfile dstfile} {
             ui_debug "activating file: $dstfile"
             # Try a hard link first and if that fails, a symlink
             try {
-                compat filelinkhard $dstfile $srcfile
+                file link -hard $dstfile $srcfile
             } catch {*} {
                 ui_debug "hardlinking $srcfile to $dstfile failed; symlinking instead"
-                compat filelinksymbolic $dstfile $srcfile
+                file link -symbolic $dstfile $srcfile
             }
         }
         default {
@@ -412,7 +395,7 @@ proc _deactivate_contents {port force} {
             # instead of the paths we currently have, users' registry won't
             # match and activate will say that some file exists but doesn't
             # belong to any port.
-            set theFile [compat filenormalize $file]
+            set theFile [file normalize $file]
             lappend files $theFile
 
             # Split out the filename's subpaths and add them to the image list
